==> laokyc_button-0.6.8.tar.gz: lib/utils/req_otp.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:laokyc_button/constant/data.dart';
import 'package:laokyc_button/model/one_id_reset_model.dart';
import 'package:laokyc_button/src/confirm_otp.dart';
import '../model/connect_refresh_token_model.dart';
import '../services/connect_refresh_token.dart';
import '../services/one_id_reset.dart';
import '../widgets/dialog_loading.dart';

Future<void> requestOTPLogin(
    BuildContext context,
    String phoneNumber,
    String clientID,
    String secret,
    String scope,
    var route,
    bool isFromConfirm) async {
  showDialog(
      context: context,
      builder: (_) {
        return DialogLoading(title: 'ກຳລັງໂຫຼດ');
      });
  String grantTypeCredentials = ConstData.grantTypeCredentials;
  String payload = jsonEncode({
    "clientID": clientID,
    "secret": secret,
    "grantType": grantTypeCredentials,
    "scope": scope,
    "username": '',
    "password": ''
  });
  ConnectRefreshTokenModel? connectTokenData =
      await connectTokenLogin(payload, context);
  if (connectTokenData != null) {
    String accessToken = connectTokenData.accessToken!;
    OneIDResetOTP? oneIDResetOTP =
        await oneIDReset(context, phoneNumber, accessToken);
    if (oneIDResetOTP != null) {
      if (isFromConfirm) {
        Navigator.pop(context);
      } else {
        Navigator.pushReplacement(context, MaterialPageRoute(builder: (_) {
          return ConfirmOTP(
            clientID: clientID,
            secret: secret,
            scope: scope,
            phoneNumber: phoneNumber,
            route: route,
          );
        }));
      }
    }
  }
}

==> laokyc_button-0.8.5.tar.gz: lib/utils/req_otp.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:laokyc_button/constant/data.dart';
import 'package:laokyc_button/model/one_id_reset_model.dart';
import 'package:laokyc_button/src/confirm_otp.dart';
import '../model/connect_refresh_token_model.dart';
import '../services/connect_refresh_token.dart';
import '../services/one_id_reset.dart';
import '../widgets/dialog_loading.dart';

Future<void> requestOTPLogin(
    BuildContext context,
    Locale? locale,
    String phoneNumber,
    String clientID,
    String secret,
    String scope,
    var route,
    bool isFromConfirm, String? fromApp) async {
  showDialog(
      context: context,
      builder: (_) {
        return DialogLoading(title: locale == const Locale('en') ? 'Loading' : 'ກຳລັງໂຫຼດ');
      });
  String grantTypeCredentials = ConstData.grantTypeCredentials;
  String payload = jsonEncode({
    "clientID": clientID,
    "secret": secret,
    "grantType": grantTypeCredentials,
    "scope": scope,
    "username": '',
    "password": ''
  });
  ConnectRefreshTokenModel? connectTokenData =
      await connectTokenLogin(payload, context, locale, 0);
  if (connectTokenData != null) {
    String accessToken = connectTokenData.accessToken!;
    OneIDResetOTP? oneIDResetOTP =
        await oneIDReset(context, phoneNumber, accessToken, 0);
    if (oneIDResetOTP != null) {
      if (isFromConfirm) {
        Navigator.pop(context);
      } else {
        Navigator.pushReplacement(context, MaterialPageRoute(builder: (_) {
          return ConfirmOTP(
            clientID: clientID,
            secret: secret,
            scope: scope,
            phoneNumber: phoneNumber,
            route: route,
            fromApp: fromApp,
            locale: locale,
          );
        }));
      }
    }
  }
}
